pub enum OptBitmapBuilder {
AllTrue {
bit_len: usize,
bit_cap: usize,
},
MayHaveFalse(BitmapBuilder),
}Expand description
A wrapper for BitmapBuilder that does not allocate until the first false is pushed. Less efficient if you know there are false values because it must check if it has allocated for each push.
Variants
Implementations
Sourceimpl OptBitmapBuilder
impl OptBitmapBuilder
pub fn reserve(&mut self, additional: usize)
pub fn extend_constant(&mut self, length: usize, value: bool)
pub fn into_opt_validity(self) -> Option<Bitmap>
pub fn subslice_extend_from_opt_validity( &mut self, bitmap: Option<&Bitmap>, start: usize, length: usize, )
pub fn subslice_extend_each_repeated_from_opt_validity( &mut self, bitmap: Option<&Bitmap>, start: usize, length: usize, repeats: usize, )
Sourcepub unsafe fn gather_extend_from_opt_validity(
&mut self,
bitmap: Option<&Bitmap>,
idxs: &[IdxSize],
)
pub unsafe fn gather_extend_from_opt_validity( &mut self, bitmap: Option<&Bitmap>, idxs: &[IdxSize], )
Safety
The indices must be in-bounds.
pub fn opt_gather_extend_from_opt_validity( &mut self, bitmap: Option<&Bitmap>, idxs: &[IdxSize], length: usize, )