pub struct BlockReader<R: Read + Seek> {
pub reader: R,
}Available on crate feature
io_ipc only.Expand description
A reader that has access to exactly one standalone IPC Block of an Arrow IPC file.
The block contains either a RecordBatch or a DictionaryBatch.
The dictionaries field must be initialized prior to decoding a RecordBatch.
Fields
reader: RImplementations
Sourceimpl<R: Read + Seek> BlockReader<R>
impl<R: Read + Seek> BlockReader<R>
pub fn new(reader: R) -> Self
Sourcepub fn record_batch_num_rows(
&mut self,
message_scratch: &mut Vec<u8>,
) -> PolarsResult<usize>
pub fn record_batch_num_rows( &mut self, message_scratch: &mut Vec<u8>, ) -> PolarsResult<usize>
Reads the record batch header and returns its length (i.e., number of rows).
Sourcepub fn record_batch_custom_metadata<'a>(
&mut self,
message_scratch: &'a mut Vec<u8>,
) -> PolarsResult<Option<Vec<KeyValueRef<'a>>>>
pub fn record_batch_custom_metadata<'a>( &mut self, message_scratch: &'a mut Vec<u8>, ) -> PolarsResult<Option<Vec<KeyValueRef<'a>>>>
Reads the record batch header and returns the custom_metadata.